<?php
/**
 * CTA Section options
 *
 * @package Theme Palace
 * @subpackage Travel Route
 * @since Travel Route 1.0.0
 */

// Add CTA section
$wp_customize->add_section( 'travel_route_cta_section', array(
	'title'             => esc_html__( 'CTA','travel-route' ),
	'description'       => esc_html__( 'CTA Section options.', 'travel-route' ),
	'panel'             => 'travel_route_front_page_panel',
) );

// CTA content enable control and setting
$wp_customize->add_setting( 'travel_route_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'travel_route_sanitize_switch_control',
) );

$wp_customize->add_control( new travel_route_Switch_Control( $wp_customize, 'travel_route_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'travel-route' ),
	'section'           => 'travel_route_cta_section',
	'on_off_label' 		=> travel_route_switch_options(),
) ) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'travel_route_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'travel_route_sanitize_page',
) );

$wp_customize->add_control( new travel_route_Dropdown_Chooser( $wp_customize, 'travel_route_theme_options[cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'travel-route' ),
	'section'           => 'travel_route_cta_section',
	'choices'			=> travel_route_page_choices(),
	'active_callback'	=> 'travel_route_is_cta_section_enable',
) ) );

// CTA btn label setting and control
$wp_customize->add_setting( 'travel_route_theme_options[cta_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_route_theme_options[cta_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'travel-route' ),
	'section'        	=> 'travel_route_cta_section',
	'active_callback' 	=> 'travel_route_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_route_theme_options[cta_btn_label]', array(
		'selector'            => '#call-to-action .view-all .btn',
		'settings'            => 'travel_route_theme_options[cta_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_route_cta_btn_label_partial',
    ) );
}

