<?php
/**
 * Package Section options
 *
 * @package Theme Palace
 * @subpackage Travel Route
 * @since Travel Route 1.0.0
 */

// Add Package section
$wp_customize->add_section( 'travel_route_package_section', array(
	'title'             => esc_html__( 'Packages','travel-route' ),
	'description'       => esc_html__( 'Packages Section options.', 'travel-route' ),
	'panel'             => 'travel_route_front_page_panel',
) );

// Package content enable control and setting
$wp_customize->add_setting( 'travel_route_theme_options[package_section_enable]', array(
	'default'			=> 	$options['package_section_enable'],
	'sanitize_callback' => 'travel_route_sanitize_switch_control',
) );

$wp_customize->add_control( new travel_route_Switch_Control( $wp_customize, 'travel_route_theme_options[package_section_enable]', array(
	'label'             => esc_html__( 'Package Section Enable', 'travel-route' ),
	'section'           => 'travel_route_package_section',
	'on_off_label' 		=> travel_route_switch_options(),
) ) );

// package title setting and control
$wp_customize->add_setting( 'travel_route_theme_options[package_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_route_theme_options[package_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-route' ),
	'section'        	=> 'travel_route_package_section',
	'active_callback' 	=> 'travel_route_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_route_theme_options[package_title]', array(
		'selector'            => '#recommended-packages .section-header h2.section-title',
		'settings'            => 'travel_route_theme_options[package_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_route_package_title_partial',
    ) );
}

// Package content type control and setting
$wp_customize->add_setting( 'travel_route_theme_options[package_content_type]', array(
	'default'          	=> $options['package_content_type'],
	'sanitize_callback' => 'travel_route_sanitize_select',
) );

$choices = array( 
		'page' 		=> esc_html__( 'Page', 'travel-route' ),
	);
if ( class_exists( 'WP_Travel' ) ) {
	$choices['trip'] = esc_html__( 'Trip', 'travel-route' );
}
$wp_customize->add_control( 'travel_route_theme_options[package_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-route' ),
	'section'           => 'travel_route_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_route_is_package_section_enable',
	'choices'			=> $choices,
) );


for ( $i = 1; $i <= 3; $i++ ) :

	// package pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_route_theme_options[package_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_route_sanitize_page',
	) );

	$wp_customize->add_control( new travel_route_Dropdown_Chooser( $wp_customize, 'travel_route_theme_options[package_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-route' ), $i ),
		'section'           => 'travel_route_package_section',
		'choices'			=> travel_route_page_choices(),
		'active_callback'	=> 'travel_route_is_package_section_content_page_enable',
	) ) );

	if ( class_exists( 'WP_Travel' ) ) {
		// slider trip drop down chooser control and setting
		$wp_customize->add_setting( 'travel_route_theme_options[package_content_trip_' . $i . ']', array(
			'sanitize_callback' => 'travel_route_sanitize_page',
		) );

		$wp_customize->add_control( new travel_route_Dropdown_Chooser( $wp_customize, 'travel_route_theme_options[package_content_trip_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Trip %d', 'travel-route' ), $i ),
			'section'           => 'travel_route_package_section',
			'choices'			=> travel_route_trip_choices(),
			'active_callback'	=> 'travel_route_is_package_section_content_trip_enable',
		) ) );
	}

endfor;
