<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Travel Route
 * @since Travel Route 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'travel_route_slider_section', array(
	'title'             => esc_html__( 'Slider','travel-route' ),
	'description'       => esc_html__( 'Slider Section options.', 'travel-route' ),
	'panel'             => 'travel_route_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'travel_route_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'travel_route_sanitize_switch_control',
) );

$wp_customize->add_control( new travel_route_Switch_Control( $wp_customize, 'travel_route_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'travel-route' ),
	'section'           => 'travel_route_slider_section',
	'on_off_label' 		=> travel_route_switch_options(),
) ) );


// Slider content type control and setting
$wp_customize->add_setting( 'travel_route_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'travel_route_sanitize_select',
) );

$choices = array( 
		'page' 		=> esc_html__( 'Page', 'travel-route' ),
	);
if ( class_exists( 'WP_Travel' ) ) {
	$choices['trip'] = esc_html__( 'Trip', 'travel-route' );
}
$wp_customize->add_control( 'travel_route_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-route' ),
	'section'           => 'travel_route_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_route_is_slider_section_enable',
	'choices'			=> $choices,
) );

for ( $i = 1; $i <= 3; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_route_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_route_sanitize_page',
	) );

	$wp_customize->add_control( new travel_route_Dropdown_Chooser( $wp_customize, 'travel_route_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-route' ), $i ),
		'section'           => 'travel_route_slider_section',
		'choices'			=> travel_route_page_choices(),
		'active_callback'	=> 'travel_route_is_slider_section_content_page_enable',
	) ) );

	if ( class_exists( 'WP_Travel' ) ) {
		// slider trip drop down chooser control and setting
		$wp_customize->add_setting( 'travel_route_theme_options[slider_content_trip_' . $i . ']', array(
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( new travel_route_Dropdown_Chooser( $wp_customize, 'travel_route_theme_options[slider_content_trip_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Trip %d', 'travel-route' ), $i ),
			'section'           => 'travel_route_slider_section',
			'choices'			=> travel_route_trip_choices(),
			'active_callback'	=> 'travel_route_is_slider_section_content_trip_enable',
		) ) );
	}

endfor;
